<?php

namespace App\Member\v1\Controller;
use App\Http\Response\HttpStatus;
use App\Http\Response\Response;
use Illuminate\Database\Eloquent\ModelNotFoundException;
use Illuminate\Routing\Controller;
use App\Member\Model\User as UserModel;
use App\Libraries\Redis\mRedis;


class User extends Controller
{

    const REDIS_AUTHKEY = "userworkspace_auth_ht";

    use \App\Traits\Controller;

    /**
     * 普通用户详情
     */
    public function show($id)
    {
        try {
            $info = UserModel::findOrFail($id , UserModel::fields);
            $info->getRelate("photographer");
        } catch (ModelNotFoundException $e) {
            return Response::error("用户未找到");
        }
        return Response::success($info);
    }

    public function getRelate($id,$relation)
    {
        try {
            $model = SetsModel::findOrFail($id , ["id"]);
            $model->getRelate($relation);
            return Response::success($model);
        } catch (ModelNotFoundException $e){
            return Response::error(HttpStatus::HttpNotFound,"用户未找到");
        }
    }

    /**
     * 更新一个HASH——CODE
     * @return array
     */
    public function code($code = null)
    {
        $redis = mRedis::getRedis();
        if ($code != null) {
            $redis->hDel(self::REDIS_AUTHKEY,$code);
        }
        $time = time();
        $code = hash("sha512",rand(0,10).$time.uniqid());
        $redis->hSet(self::REDIS_AUTHKEY,$code,['expire' => time() + 3600]);
        return Response::success($code);
    }

    public function getUserByHashCode($code)
    {
        $redis = mRedis::getRedis();
        $user = $redis->hGet(self::REDIS_AUTHKEY,$code);
        if (isset($user['expire']) && $user['expire'] < time()) {
            return Response::error("已过期",HttpStatus::HttpTimeout);
        }
        if (isset($user) && isset($user['id'])) {
            return Response::success(UserModel::getUserInfo($user['id']));
        }else{
            return Response::error();
        }
    }
}